@@ -6,11 +6,11 @@ Kernel
 </category>
 
 <name>  
-Kernel-antiX_32bit_latest
+Kernel-antiX_32bit_latest_meltdown_patched
 </name>
 
 <description>  
-antiX Kernel 32 bit (4.20.0-486)
+antiX Kernel 32 bit Meltdown, Spectre and Foreshadow patched (4.20.0-486)
 </description>
 
 <installable>
